// Copyright (c) 2000-2002 David Muse
// See the COPYING file for more information.

#include <rudiments/environment.h>

#include <time.h>
#include <sys/types.h>
#ifdef RUDIMENTS_HAS_THREADS
	#include <pthread.h>
#endif
